# Cookbook

Check out the Beehive cookbook on Github [here](https://github.com/BeehiveHQ/beehive-ai/tree/main/beehive/cookbook).

It's still a WIP, so please raise an issue if you'd like to see additional concepts demonstrated!
